EasyExtend.langlets.p4d.bytelet

Package EasyExtend :: Package langlets :: Package p4d :: Module bytelet |
[hide private]
[frames] | no frames]

# Module bytelet

Classes | [hide private]
| Hex Generic hexadecimal object.
| Bin
| Flow
| FlowLen
| FlowLenBER
| FlowLenRaw
| FlowFieldVal
| ByteletList Class used to represent lists of P4D objects.
| Bytelet Bytelets are flexible data structures used for binary serialization.
| ByteletSchema

Variables | [hide private]
| LEN = `FlowLenBER()`
| RAWLEN = `FlowLenRaw()`
| VAL = `FlowFieldVal()`